==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/help/ja-sjis/xtbsupdateHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* R}hwv,man,musahi GUI ʃbZ[WǗ                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* R}h̃^Cg                                                         */
/* R}hwv̍ŏ̍sɕ\\                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "񕪒TɂXV"

/*----------------------------------------------------------------------------*/
/* p[^                                                                 */
/* R}hwv USAGE:Ƃ"L[[h XXXT"\\ ex)-k L[ږXg*/
/* flag̃IvV̓R}hwvOPTIONS)Ƃĕ\\ ex)-z : Wo͂̈k*/
/*----------------------------------------------------------------------------*/
/*-k*/
#define KEYT "L[ږXg"
#define KEYC "ΏۍځFږ%l"
#define KEYF NULL

/*-v*/
#define VALT "lXg"
#define VALC "la,lb:lc,lc~ld"

/*-f*/
#define FLDT "ږXg"
#define FLDC "XVΏۍځFږ%XVl"
#define FLDF NULL

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*----------------------------------------------------------------------------*/
/* v                                                                       */
/* R}hwvSUMMARY:Ƃĕ\\                                     */
/* HTMLwvmanɂ́AHELPD̏Ɍ`ŕ\\                   */
/*----------------------------------------------------------------------------*/
#define HELPS "-kŎw肵ڂƒlőΏۍsA-fŎw肵ڂƒlɂčXVȂB̓f[^͂炩xtfixlenɂŒ蒷ϊĂKvB"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtbsupdate -k i -v َq -f ݌ɐ%4 -i dat.xt\n\
xtbsupdate -k i, -v َq: -f ݌ɐ%4,%5 -i dat.xt\n\
xtbsupdate -k t, -v 20030819:100000~110000 -f \\%1 -i dat.xt\n\
xtbsupdate -k t, -v 20030819:100000~110000,20030820 -f \\%1 -i dat.xt\n\
"

/*----------------------------------------------------------------------------*/
/* QƃR}h(KJ}ŋ؂A󔒂͗pȂ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtfixlen,xtbsselstr"

/*----------------------------------------------------------------------------*/
/* ҂ɂ                                                               */
/* R}hwvɂ͕\\Ȃ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* oO|[g                                                               */
/* o^΃R}hwvBUG REPORT:ɕ\\B                  */
/* o^Ȃ(#define HELPB "")\\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* z[y[W                                                               */
/* o^΃R}hwvINFORMATION:ɕ\\B                 */
/* o^Ȃ(#define HELPH "")\\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH

==> musashi-core-1.0.4-pre3.tar.gz: musashi-core-1.0.4-pre3/help/ja-sjis/xtbsupdateHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* R}hwv,man,musahi GUI ʃbZ[WǗ                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* R}h̃^Cg                                                         */
/* R}hwv̍ŏ̍sɕ\                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "񕪒TɂXV"

/*----------------------------------------------------------------------------*/
/* p[^                                                                 */
/* R}hwv USAGE:Ƃ"L[[h XXXT"\ ex)-k L[ږXg*/
/* flag̃IvV̓R}hwvOPTIONS)Ƃĕ\ ex)-z : Wo͂̈k*/
/*----------------------------------------------------------------------------*/
/*-k*/
#define KEYT "L[ږXg"
#define KEYC "ΏۍځFږ%l"
#define KEYF NULL

/*-v*/
#define VALT "lXg"
#define VALC "la,lb:lc,lc~ld"

/*-f*/
#define FLDT "ږXg"
#define FLDC "XVΏۍځFږ%XVl"
#define FLDF NULL

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*----------------------------------------------------------------------------*/
/* v                                                                       */
/* R}hwvSUMMARY:Ƃĕ\                                     */
/* HTMLwvmanɂ́AHELPD̏Ɍ`ŕ\                   */
/*----------------------------------------------------------------------------*/
#define HELPS "-kŎw肵ڂƒlőΏۍsA-fŎw肵ڂƒlɂčXVȂB̓f[^͂炩xtfixlenɂŒ蒷ϊĂKvB"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtbsupdate -k i -v َq -f ݌ɐ%4 -i dat.xt\n\
xtbsupdate -k i, -v َq: -f ݌ɐ%4,%5 -i dat.xt\n\
xtbsupdate -k t, -v 20030819:100000~110000 -f \%1 -i dat.xt\n\
xtbsupdate -k t, -v 20030819:100000~110000,20030820 -f \%1 -i dat.xt\n\
"

/*----------------------------------------------------------------------------*/
/* QƃR}h(KJ}ŋ؂A󔒂͗pȂ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtfixlen,xtbsselstr"

/*----------------------------------------------------------------------------*/
/* ҂ɂ                                                               */
/* R}hwvɂ͕\Ȃ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* oO|[g                                                               */
/* o^΃R}hwvBUG REPORT:ɕ\B                  */
/* o^Ȃ(#define HELPB "")\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* z[y[W                                                               */
/* o^΃R}hwvINFORMATION:ɕ\B                 */
/* o^Ȃ(#define HELPH "")\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH
